@@ -1,5 +1,5 @@
 import smtplib
-import Mail
+from email_sender import Mail
 
 class Email:
     def __init__(self, server, username, password):
